@@ -4,11 +4,10 @@ use MIDI::RtController ();
 
 my $input_names = shift || 'keyboard,pad,joystick'; # midi controller devices
 my $output_name = shift || 'usb'; # midi output
-
-my $verbose = 1;
+my $verbose     = shift || 0;
 
 my @inputs = split /,/, $input_names;
 
-my $controllers = MIDI::RtController::open_controllers($input_names, $output_name, $verbose);
+my $controllers = MIDI::RtController::open_controllers(\@inputs, $output_name, $verbose);
 
 $controllers->{ $inputs[0] }->run;
